@@ -20,6 +20,7 @@ familyname: Shellingford
 nickname: Sheryl
 birthday: March 31
 voiced_by: Suzuko Mimori
+nickname_voiced_by: mimorin
 toys: Psychokinesis
 
 
@@ -30,5 +31,6 @@ familyname: シェリンフォード
 nickname: シャロ
 birthday: 3/31
 voiced_by: 三森 すずこ
+nickname_voiced_by: みもりん
 toys: サイコキネシス
 name_separator: ・
